import { InfoBox } from "../components/Boxes";
import { TabButtonRow } from "../components/Buttons";
import Collapsible from "../components/Collapsible";
import { SupScrollLink } from "../components/ScrollLink";
import { H4} from "../components/Headings";
import { ButtonRowTabs } from "../components/Tabs";
import PieChart from "../components/Graph";
import PreCyse from "../components/precyse";


import { Section, Subesction } from "../components/sections";
import { symptomdata, SymptomDatensatz } from "../data/symptom-data";
import { drugdata, DrugDatensatz } from "../data/drug-data";
import { useTabNavigation } from "../utils/TabNavigation";
import PrimeEditingComplex from "../components/Complex-svg";
import { useNavigation } from "../utils";

export function Description() { 
    useTabNavigation();
    const {goToPagesAndOpenTab} = useNavigation();
    const {goToPageAndScroll} = useNavigation();
  return (
      <div className="row mt-4">
        <div className="col">
            <Section title="Abstract" id="Abstract">
                <p id="obenindescription" >We are proud to introduce <PreCyse/>, our next-generation Prime Editing technology aimed at developing an innovative gene therapy for cystic fibrosis, specifically targeting the most common mutation, <b>F508del</b> of the CFTR gene. PreCyse is designed to address key limitations in current treatments, including limited size, speed, precision, and long-term effectiveness. Our approach integrates <b>PrimeGuide</b>, a highly optimized Prime Editing system, with <b>AirBuddy</b>, a novel lipid nanoparticle (LNP) delivery platform. The <b>SORT LNPs</b> used in AirBuddy are optimized for pulmonary delivery, offering precise organ targeting and structural stability throughout the inhalation process. As a Postdoc at the Broad Institute of MIT and Havard—where Prime Editing was first pioneered—observed, “<i>Everyone is looking for smaller prime editors</i>” and PrimeGuide embodies this vision by utilizing a smaller, more efficient editing complex. Unlike current treatments, which often require frequent administration and provide only temporary relief, PreCyse is developed as a monthly applied therapy with the potential for longer-lasting results, reducing the frequency of use and improving patient outcomes. By lowering costs and improving accessibility, PreCyse aims to offer a more advanced and user-friendly cure for cystic fibrosis. </p>
            </Section>
            <Section title="Our Motivation" id="Our Motivation">
                    <div className="row align-items-center">
                        <div className="col" >
                        <p>Our project started with a personal story. Rather than being driven purely by academic curiosity, our motivation came from someone close to one of our team members — Max Beckmann, a friend who has lived with Cystic Fibrosis (CF) since his birth. Specifically, he carries the F508del mutation, the most common genetic cause of the disease. Seeing the impact of CF on his daily life—frequent treatments and physical strain—made us realize how much more can be done to improve the lives of those affected, which inspired us to pursue this project. </p>
                        <p>As we explored Cystic Fibrosis further, we were struck by how widespread it is, being the most common genetic disorder in Germany. Approximately 70% of those with CF are specifically affected by the F508del mutation [1]. This mutation is the most prevalent and well-studied of the thousands of genetic variations that cause CF, making it an important focus of research and intervention. In fact, about 90% of Europeans and individuals of European descent with CF have at least one F508del allele [2, 3]. This widespread prevalence highlighted the significance of our project—not just for our friend, but for the thousands of others affected by this mutation across Europe and beyond. </p>
                        </div>
                        <div className="col" >
                            <img className="img" src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/> 
                        </div>    
                    </div>
                    <p>By focusing on the F508del mutation, we also hope to contribute valuable insights to the global cystic fibrosis community. Although this mutation is most common in European populations, it is also found in other regions around the world [4, 5]. Our research could thus help inform treatment strategies and health policies on an international scale. </p>
                    <p>With several team members focusing their studies on biomedical fields, we began by examining the current landscape of CF treatments. It quickly became clear that, despite recent progress, there is still no cure. Most therapies, such as CFTR modulators, focus on managing symptoms and improving lung function rather than addressing the underlying cause of the disease [6]. This realization led us to explore gene-editing technologies, thus leading us to Prime Editing—a next generation gene editing method—captured our attention. </p>
                    <p>While Prime Editing holds great promise, we found that its application for cystic fibrosis, particularly the F508del mutation, had not been fully explored. Recognizing this gap in the research inspired us to take on the challenge of optimizing Prime Editing for this specific mutation. Our mission became clear: we want to contribute to the development of a potential therapeutic approach for cystic fibrosis, specifically targeting the F508del mutation with prime editing, and bring us closer to a long-term solution for patients. </p>
            </Section>
            <Section title="Cystic Fibrosis" id="Cystic Fibrosis">
                <Subesction title="Overview" id="Cystic Fibrosis1">
                    <div className="row align-items-center">
                        <div className="col">
                            <p data-aos="zoom-y-out" >Cystic Fibrosis (CF) is a common life-limiting genetic disorder, particularly affecting the Caucasian population, with approximately 162,400 people worldwide living with the condition [1]. Statistically, about one in every 3,300 white newborns is born with CF [2]. And according to the German Cystic Fibrosis Registry, the average life expectancy for children born with CF in 2021 was around 57 years [3], highlighting the severe and life-shortening nature of the disease. </p>
                            <p>The modern understanding of CF dates back to 1932 when Dr. Dorothy Andersen, a pediatric specialist, first described the disease and coined the term "Cystic Fibrosis" [4]. In Germany, it is commonly known as "Mukoviszidose," derived from the Latin words meaning "mucus" and "viscous" [4], emphasizing the characteristic thick, sticky mucus that defines the condition [5, 6]. </p>
                            <p>Genetic research has identified over 1,700 mutations in the CFTR (Cystic Fibrosis Transmembrane Conductance Regulator) gene, with the ∆F508 mutation being the most common, affecting about 70% of CF patients. This mutation prevents the proper folding of the CFTR protein, significantly impairing its function [7]. </p>
                            <p>The CFTR protein regulates the flow of chloride ions across the membranes of cells in the lungs, digestive system, and other organs. This ion flow is essential for drawing water into surrounding tissues, which helps maintain the proper hydration and consistency of mucus. In patients with CF, the disruption of this process prevents sufficient water from entering the mucus, making it abnormally thick and sticky. The accumulation of this mucus leads to an obstruction of airways and digestive ducts, resulting in chronic lung infections, inflammation, impaired digestion, and malnutrition[8]. </p>
                            <div className="casettecontainer" >
                                <figure> 
                                <img className="img" src="https://static.igem.wiki/teams/5247/project-description/lung-ephitel-biorender.png"/>
                                    <figcaption> 
                                        <b>Figure 1: </b> 
                                        Lung ephitelium of human with correct CFTR expression (left) and Cystic Fibrosis (right)
                                    </figcaption> 
                                </figure> 
                            </div> 
                            <Collapsible id="classes-mutations-collapsible" title="Different classes of mutations">
                            <p>The mutations can be divided into <u>six classes</u> <SupScrollLink label="9"/>:</p>
                            <p><b>Class I</b> mutations prevent the synthesis of CFTR proteins altogether, meaning no channels are produced.</p>
                            <p><b>Class I</b> mutations, which include the common F508del mutation (responsible for about 85% of cases <SupScrollLink label="10"/>), disrupt the maturation process of the protein. As a result, the defective channels are quickly degraded by the cell.</p>
                            <p><b>Class I</b> mutations, known as “gating” mutations, reduce the likelihood that the CFTR channel will open correctly, impairing its function.</p>
                            <p><b>Class IV, V</b> and <b>VI</b> mutations are rare. These mutations result in the production of unstable or inefficient CFTR proteins, which do not function adequately and are produced in insufficient numbers.</p>
                            </Collapsible>
                            <p>The prevalence of CF varies globally, with higher concentrations of cases in Europe, North America, and parts of Oceania. This geographic variation underscores the need for regionally tailored healthcare solutions. </p>
                            </div>
                                <div className="casettecontainer">
                                <img src="https://static.igem.wiki/teams/5247/charts-maps/cfper10-000.png"></img>
                                </div>
                            </div>
                            <p>CF is often diagnosed early through newborn screening programs, which detect elevated levels of immunoreactive trypsinogen (IRT). A positive result typically leads to a sweat test, the gold standard for diagnosing CF, which measures the concentration of chloride in sweat. </p>
                            <p>Although there is currently no cure for CF, patients must manage the disease throughout their lives, relying on treatments that alleviate symptoms but do not address the root cause. This lifelong management imposes significant financial burdens on affected families and healthcare systems, particularly in regions with a high prevalence of CF [9]. In recent years, <b>CFTR modulators</b>, which target the underlying genetic defect, have offered new hope for many patients. </p>
                </Subesction>
                <Subesction title="The CFTR Protein" id="Cystic Fibrosis2">
                    <p>The CFTR (Cystic Fibrosis Transmembrane Conductance Regulator) protein is an ion channel that facilitates the movement of chloride ions across epithelial cell membranes [1][2]. This movement is essential for controlling the flow of water in tissues such as the lungs and intestines [3]. This increase in ion concentration in the extracellular space draws water out of the cells and into the surrounding mucus or fluid, ensuring it stays thin and mobile [4].</p>
                    <p>The Cystic Fibrosis Transmembrane Conductance Regulator (CFTR) protein is a specialized protein that plays a crucial role in maintaining the balance of ions and water on the surface of certain cells, particularly in the lungs, pancreas, and other organs [2][5]. </p>
                    <H4 text="Structure of CFTR" id="structure-cftr" />
                        <p>CFTR is a large protein embedded in the cell membrane. It belongs to a family of proteins known as ABC transporters (ATP-Binding Cassette transporters), which typically move molecules across cell membranes [1]. CFTR, however, is unique because it functions as an ion channel rather than a transporter [3]. </p>
                        <p>The protein consists of several important regions: </p> 
                        <ul>
                            <li><b>Two transmembrane domains (TMDs)</b>: These span the cell membrane and create the channel through which ions can flow [4].</li>
                            <li><b>Two nucleotide-binding domains (NBDs)</b>: Located on the cytoplasmic side of the membrane, these domains bind and hydrolyze ATP (adenosine triphosphate). ATP binding and hydrolysis regulate the opening and closing of the chloride channel [1] [5].</li>
                            <li><b>Regulatory (R) domain</b>: This domain is unique to CFTR and controls the activity of the protein. It requires phosphorylation by protein kinase A (PKA) to activate the ion channel [2][3].</li>
                        </ul>
                        <div className="row align-items-center">
                        <figure>
                            <div className="row">
                            <div className="col">
                                <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/>
                            </div> 
                            <div className="col">
                                <img src="https://static.igem.wiki/teams/5247/placeholders/placehilderperson.jpeg"/>
                            </div>
                            </div>
                            <figcaption><b>Figure 2: </b> 3D model of the CFTR protein in its wildtype form (left) and with the F580del mutation (right) </figcaption>
                        </figure>
                            <div className="col">
                            <div className="figure-wrapper">
                                <figure>
                                    <div className="col gif-wrapper">
                                        <img className="CFTR-gif" src="https://static.igem.wiki/teams/5247/fanzor/cftr-wt.gif"></img>
                                    </div>
                                    <figcaption> <b>Figure x.</b></figcaption>
                                </figure>
                            </div>
                    <H4 text="Function of CFTR" id="function-cftr" />     
                        <p>CFTR functions primarily as a chloride ion channel. It is responsible for transporting chloride ions (Cl⁻) across epithelial cell membranes [1][4]. Here's how it works:</p> 
                        <ol>
                            <li><b>Regulation by phosphorylation</b>: The R domain must first be phosphorylated by PKA to allow channel activation. This phosphorylation is often triggered by cyclic AMP (cAMP), a signaling molecule [5].</li>
                            <li><b>Opening the channel</b>: Once the R domain is phosphorylated, ATP binds to the NBDs, causing conformational changes that open the chloride channel [2].</li>
                            <li><b>Chloride transport</b>: With the channel open, chloride ions move from inside the cell to the outside. This movement of chloride helps draw water out of the cell, thinning mucus and maintaining proper hydration of the epithelial surfaces [3][4].</li>
                            <li><b>Closing the channel</b>: Hydrolysis of ATP causes the channel to close after a certain period, tightly regulating chloride transport [1].</li>
                        </ol> 
                        <p>CFTR plays a critical role in maintaining the fluid balance on the surfaces of tissues such as the airways, digestive tract and sweat glands. By allowing chloride ions to flow out of the cells, CFTR ensures that water follows, preventing the accumulation of thick, sticky mucus [3].</p>
                    <H4 text="CFTR in Cystic Fibrosis" id="CFTR-in-cftr" />    
                        <p>In the lungs, this water movement is crucial for maintaining a thin, slippery layer of mucus that can trap and remove particles like dust and bacteria. The mucus is then moved out of the lungs by the action of cilia, tiny hair-like structures on the surface of epithelial cells. When the CFTR protein is defective, as in cystic fibrosis, chloride cannot properly exit the cells. This disrupts the osmotic gradient, preventing water from entering the mucus. As a result, the mucus becomes thick and sticky, making it difficult to clear and creating an ideal environment for bacterial infections, which leads to chronic inflammation and lung damage over time.</p>
                        <p>In the intestines, CFTR regulates fluid secretion into the digestive tract, which is vital for the normal movement of digestive contents. Without proper CFTR function, water movement is reduced, leading to thickened digestive fluids, blockages, and impaired nutrient absorption. This contributes to malnutrition and other digestive complications in cystic fibrosis patients. </p>
                        <p>By correcting the genetic mutations that lead to CFTR malfunction, such as the ∆F508 mutation, we aim to restore the proper balance of chloride and water movement, which is crucial for preventing the buildup of mucus and ensuring normal function in both the respiratory and digestive systems.</p>
                        </div>
                    </div>
                </Subesction>
                <Subesction title="F508del" id="Cystic Fibrosis3">
                    <p>More than 1,000 mutations in the CFTR gene are responsible for the development of cystic fibrosis. The most common variant is the F508del mutation, found in approximately 70% of affected individuals of Caucasian descent in Canada, Northern Europe, and the United States [18]. It is estimated that around 90% of people with cystic fibrosis in Europe and those of European heritage carry at least one F508del allele [19, 20]. Research suggests that this mutation originated in Western Europe at least 5,000 years ago [19].</p>
                    <p>The F508del mutation involves the deletion of three nucleotides, "CTT," at position 508, which removes a phenylalanine residue without causing a frameshift. This deletion impairs the kinetic and thermodynamic folding of the NBD1 domain [21]. As a result, the CFTR protein not only misfolds but also experiences defects in trafficking and premature degradation, leading to a reduction in its surface expression [22]. This specific mutation is particularly severe because it affects both the production and function of CFTR, resulting in a more aggressive disease course. Consequently, patients with the F508del mutation may respond better to CFTR modulators, which target these specific defects in protein folding and function.</p>
                    <Collapsible id="statistical-distribution-collapsible" title="Statistical distribution of F508del mutations">
                        <p>In 2023, a comprehensive analysis was conducted to assess the distribution of mutations in the CFTR gene associated with cystic fibrosis (CF) worldwide. Data was sourced from two reputable databases: the <a href="https://cftr.iurc.montp.inserm.fr/cgi-bin/variant_list.cgi" title="CFTR-database-1" >CFTR Mutation Database</a> and the <a href="https://cftr2.org/mutations_history" title="CFTR-database-2" >CFTR2 Database</a>. </p>
                        <p>The results indicate the following distribution of CFTR mutation types and their frequencies in percent: </p>
                        <div className="row align-items-center">
                            <div className="col" >
                                <ul>
                                    <li><b>Insertions (ins)</b>: 0.00088%</li>
                                    <li><b>Deletions (del)</b>: 72.64%</li>
                                    <li><b>Substitutions (subs)</b>: 23.84%</li>
                                    <li><b>Insertions/Deletions (indel)</b>: 0,00485%</li>
                                    <li><b>Other mutations</b>: 0,00370%</li>
                                </ul>
                                </div>
                            <div className="col" >
                                <PieChart /> {/* Render the PieChart component */}
                            </div>    
                        </div> 
                    </Collapsible>  
                    <p>Overall, the statistical distribution of CFTR mutations reveals significant variations in mutation types and their frequencies worldwide, with deletions (72.64%) being the most common mutation type. This underscores the need for continued research and monitoring of these genetic variations to improve patient care and treatment strategies. CF not only affects the directly affected organs, but also many other areas of the body that are indirectly affected by the extent of the disease, e.g. through the condition of diseased organs. </p>
                    <div className="row">
                        <div className="col">
                            <PieChart/>
                        </div>
                        <div className="col"></div>
                    </div>
                </Subesction>
                <Subesction title="Symptoms" id="Cystic Fibrosis4">
                    <p>Since the CFTR gene is expressed in nearly all tissues of the human body, cystic fibrosis affects as a metabolic disease a wide range of vital organs.</p>
                    <Collapsible id="symptoms-collapsible" title="How the symptoms affect different parts of the body" >
                    <TabButtonRow data={symptombuttonrowdata} opentype="meditabs" closing=""/>
                    <ButtonRowTabs data={symptombuttonrowdata} cla="meditabs"/> 
                    </Collapsible>
                </Subesction>
                <Subesction title="Diagnosis" id="Cystic Fibrosis5">
                    <p>With Cystic Fibrosis being a hereditary disease, the diagnostic methods have evolved significantly [1][2]. Early diagnosis is crucial, as it allows for timely interventions that can improve the quality of life and longevity for CF patients [1][3]. With advancements in screening and diagnostic tools, many individuals are diagnosed shortly after birth, enabling early management of the disease [3][4].</p>
                    <p>Cystic fibrosis can be diagnosed through a variety of methods, often starting in infancy or even before birth [2][5]. The most common diagnostic test is the newborn screening, which involves a blood test that checks for elevated levels of a protein called immunoreactive trypsinogen (IRT) [4][6]. Elevated IRT levels can indicate potential CF, prompting further testing [6]. </p>
                    <Collapsible id="newborn-screening-collapsible" title="Newborn screening">
                        <p>Newborn screening for Cystic Fibrosis (CF) has been a major advancement in early detection and management, leading to significantly improved patient outcomes. This practice, which started in the late 1970s, became more widespread in the 1980s. The screening typically involves a blood test within the first few days of life, measuring immunoreactive trypsinogen (IRT), a marker that is elevated in newborns with CF. Elevated IRT levels prompt further genetic testing to identify CFTR mutations [25]. If mutations are found, a sweat chloride test is often conducted to confirm the diagnosis. </p>
                        <p>Many countries, including the United States, Canada, the United Kingdom, Australia, and several European nations, have implemented newborn screening programs for CF. However, a survey of CF screening in Europe revealed that the implementation of such programs varies widely, with some countries adopting more comprehensive protocols than others [26]. Early diagnosis through screening offers significant benefits, such as improved growth, better lung function, and overall enhanced health outcomes [27]. The discovery of the CFTR gene has further refined diagnostic techniques and underscored the crucial role of newborn screening in the early detection and management of CF. </p>
                        <p>Technological advancements and improved medical procedures have greatly transformed the diagnosis of cystic fibrosis. While newborn screening has revolutionized early detection and treatment, traditional methods such as the sweat test and symptom observation continue to play a vital role, particularly in regions where screening programs are not yet widely available.</p>
                    </Collapsible>
                    <p>Another widely used method is the sweat test, which measures the concentration of chloride in a person's sweat [2][7]. CF patients typically have higher-than-normal chloride levels due to defective CFTR protein function [2][7]. While the sweat test is non-invasive and reliable for indicating CF, it is limited in scope [7]. For definitive diagnosis and to guide specific treatments, a genetic analysis is usually required to identify the exact CFTR mutation, such as the F508del mutation [5][8].</p>
                    <Collapsible id="sweat-test-collapsible" title="Sweat test">
                        <p>Traditionally, Cystic Fibrosis (CF) has been diagnosed using the sweat test, which measures chloride levels in sweat. A chloride level below 40 mmol/L (millimoles of chloride per litre of sweat) is considered normal and unlikely to indicate CF. Levels between 40 and 60 mmol/L require further investigation, while levels above 60 mmol/L strongly suggest the presence of CF [28].</p>
                        <p>This quick and painless test has been the gold standard for CF diagnosis for many years. Despite its accuracy, the sweat test requires specialized lab personnel and can be difficult to perform on newborns. While diagnosing CF based on symptoms can be useful, it is not always reliable, particularly in mild or atypical cases.</p>
                    </Collapsible>
                </Subesction>
                <Subesction title="Treatment" id="Cystic Fibrosis6">
                    <p>Current Cystic fibrosis treatments focus on managing symptoms, slowing disease progression, and improving quality of life [1][2]. Since there is still no cure for CF, treatment is typically lifelong and involves multiple approaches, including medications, physical therapy, and dietary adjustments [3][4]. </p>
                    <p>The primary goal of CF treatment is to clear the thick mucus from the lungs to prevent infections and improve breathing [2][5]. Airway clearance techniques, such as chest physiotherapy, are often used alongside inhaled medications, like bronchodilators and mucolytics, to thin the mucus and open the airways [5][6]. Antibiotics are frequently prescribed to treat or prevent lung infections caused by trapped bacteria in the airways [2][4].</p>
                    <p>One of the most significant advances in CF treatment has been the development of CFTR modulators, which target the underlying protein dysfunction caused by mutations in the CFTR gene [7][8]. These drugs, such as ivacaftor, lumacaftor, and elexacaftor, work by improving the function of the defective CFTR protein, particularly in patients with specific mutations like F508del [7][8]. While CFTR modulators can dramatically improve lung function and overall health in many patients, they are not effective for all CFTR mutations and often are very expensive [7][8].</p>
                    <p>Digestive enzyme supplements are essential for CF patients who suffer from pancreatic insufficiency, helping them to absorb nutrients from food [3][9]. Additionally, high-calorie diets and vitamins are recommended to support growth and maintain body weight [3][9].</p>
                    <p>Although current treatments can significantly improve quality of life and life expectancy, managing CF remains a daily challenge for patients [1][2]. Continued research into gene therapy and other innovative treatments offers hope for more permanent solutions in the future [10].</p>
                    <Collapsible id="drugs-collapsible" title="Different types of drugs" >
                    <TabButtonRow data={medibuttonrowdata} opentype="symptabs" closing=""/>
                    <ButtonRowTabs data={medibuttonrowdata} cla="symptabs"/>
                    </Collapsible>
                    <H4 text="CF treatment with gene therapy"></H4>
                    <p>While mentioned medications have improved the quality of life for numerous CF patients, they only manage symptoms rather than cure the disease. Moreover, most of them are expensive and not world-wide accessible. Our research is focused on the development of a gene therapy that targets the underlying cause of CF by correcting the defective CFTR gene. <PreCyse/> aims to halt disease progression and reduce the treatment burden for patients.</p>
                </Subesction>
            </Section>
            <Section title="Approach" id="Approach">
                <Subesction title="Mechanism" id="Approach1">
                <p>The development of an improved Prime Editing complex holds great promise for advancing gene editing technologies. Our enhanced system, Prime Guide, addresses key limitations of conventional Prime Editing by focusing on four main areas: editing efficiency, precision, size, and safety. Prime Guide has been designed to target the ΔF508 mutation in cystic fibrosis with high accuracy, while minimizing off-target effects. By optimizing the pegRNA, reverse transcriptase, and nickase components, we aim to deliver precise and efficient genetic modifications.</p>
                <p>As shown in the image, we developed two potential configurations for Prime Guide, each using a different nickase: one based on the Fanzor (nSpuFz1) nickase and the other on a CasX (nPlmCasX) nickase. Both configurations are designed to improve the precision and stability of the Prime Editing system. The pegRNA scaffold, reverse transcriptase (PE6c), and primer binding site (PBS/RTT) work together in both systems to introduce precise edits, with the La(1-194) enhancing stability and function.</p>
                <InfoBox title="Prime Editing" id="prime-editing">
                    <details>
                        <summary>Prime editing is a new method of gene editing based on an RNA-Protein complex. It was developed by a group of researchers revolving around Professor David Liu from Harvard University in 2019. <SupScrollLink label="9"/></summary>
                        <p></p>
                        <p><b>How does Prime Editing work?</b></p>
                        <p>Prime Editing builds on the well-known CRISPR technology, offering a more precise and controlled approach to DNA modification. Traditional CRISPR-Cas9 methods typically involve creating double-strand breaks in DNA, which can be repaired by the cell in ways that might introduce unintended mutations. Prime Editing, by contrast, circumvents this issue by using a more refined method that avoids double strand breaks altogether [31].</p>
                        <p>At the heart of Prime Editing is a fusion protein, which combines two key components: a modified Cas9 enzyme, known as a "nickase," and a reverse transcriptase enzyme. The nickase is responsible for making a single strand cut in the DNA, unlike the traditional Cas9, which cuts both strands. This single strand cut minimizes the risk of unintended mutations or large-scale DNA damage. The reverse transcriptase attached to the nickase then modifies the DNA at the targeted site by incorporating new genetic information.</p>
                        <p>To guide this process, Prime Editing uses a specialized RNA molecule known as prime editing guide RNA (pegRNA). This pegRNA serves two functions: it directs the Cas9 nickase to the specific location on the genome, and it carries a template for the desired DNA modification. Now, let’s go through the process in more detail, referencing the image above.</p>
                        <ol>
                            <li><b>DNA Nicking</b>: In the first step (top left in the image), the Cas9 nickase, guided by the pegRNA, binds to the target genomic DNA and creates a single-strand break, or "nick," at the precise location. This is a key difference from standard CRISPR, where both DNA strands are cut, increasing the risk of unwanted mutations.</li>
                            <li><b>Primer Binding and Reverse Transcription</b>: Once the DNA is nicked, the primer binding site (PBS) on the pegRNA hybridizes with the exposed single-stranded DNA, as shown in the middle of the image. This alignment allows the reverse transcriptase (RT) enzyme, also fused to the nickase, to begin copying the edit into the target DNA. The reverse transcriptase uses the template encoded within the pegRNA to create a complementary DNA sequence (depicted as the new sequence in the image), ensuring the corrected genetic sequence is accurately inserted into the genome.</li>
                            <li><b>Flap Formation and Equilibration</b>: The process continues as the reverse transcriptase copies the new genetic sequence into the DNA strand, creating what is called a "3' flap" (as shown in the bottom part of the image). This flap contains the newly edited sequence. At this point, there is an equilibration between the new flap (which encodes the intended edit) and the unedited 5' flap, which still contains the original, unmodified DNA sequence. The cell's natural mechanisms typically degrade the unedited 5' flap, favoring the integration of the 3' flap encoding the edit.</li>
                            <li><b>Flap Resolution and Final Editing</b>: In some cases, an additional nick (seen in the PE3/PE5 systems in the image) is introduced in the non-target DNA strand to promote repair and favor the incorporation of the edit. This step increases the efficiency of Prime Editing by ensuring that the newly edited strand is preferentially used during the cell's DNA repair process. The mismatch repair (MMR) system of the cell also plays a role in determining whether the edit is retained or reverted to the original sequence. For systems like PE4 and PE5, inhibition of the mismatch repair system (e.g., by MLH1dn) further promotes the integration of the desired edit.</li>
                            <li><b>Final outcome</b>: Once the unedited flap is degraded and the new sequence is integrated, the cell completes the repair, and the edit becomes permanently incorporated into the DNA. As shown in the diagram, the result is a successful genetic modification, where the new, corrected sequence replaces the original faulty sequence.</li>
                        </ol>
                        <figure> 
                            <img className="img" src="https://static.igem.wiki/teams/5247/project-description/illustration-primeediting.webp"/>
                            <figcaption> 
                                <b>Figure 4: </b> 
                                Illustration of the Prime Editing process and its possible outcomes
                            </figcaption> 
                        </figure> 
                        <p>Overall, there are many different Prime Editing systems with a variety of components and complexity, starting from PE2 up to PE7. Possible edits could integrate substitutions, inserts and deletions in the range of one base up to hundreds of nucleotides, with gradually decreasing editing efficiency. Therefore Prime Editing technology allows targeted modifications of specific genes. </p>
                    </details>
                </InfoBox> 
                <p>However, the Prime Editing complex is relatively large, posing challenges for therapeutic delivery<SupScrollLink label="3"/>. Additionally, Prime Editing has been shown to be relatively inefficient in terms of gene editing rates, which could limit its therapeutic utility<SupScrollLink label="4"/>. Our project aims to enhance the Prime Editing approach by miniaturizing its components and enhancing its efficiency, as well as precision. </p>
                <div className="row">
                    <div className="col">
                        <img className="img" src="https://static.igem.wiki/teams/5247/project-description/primeguide.png"/>
                    </div>
                    <div className="img-right img-half col"><PrimeEditingComplex/></div>
                </div>
                <p>To develop our innovative Prime Editing system, Prime Guide, we worked closely with several leading experts in the field. Among them were Mattijs Bulcaen, Makato Saito, Dr. Hammer, Jan-Phillipp Gerhard and Prof. Kristian Müller, whose insights helped guide our decisions. Prime Guide is a highly specialized Prime Editing complex, designed to target the F508del mutation in cystic fibrosis with precision and efficiency. </p>
                <p>Our Prime Guide system consists of carefully selected components, each optimized for its role. For the nickase, we chose between SpuFz1 and CasX nickases due to their smaller size and structural advantages, which suggest increased stability for the pegRNA within the Prime Editing complex. Smaller nickases also provide benefits in terms of overall efficiency and ease of delivery, aligning with the compact design we aimed for.</p>
                <Collapsible id="fanzorcas-collapsible" title="Cas vs. Fanzor"> 
                    <p>Fanzor is a recently discovered eukaryotic endonuclease, initially identified in fungi. Compared to the Cas9 endonuclease, Fanzor is significantly smaller and also RNA-guided. SpuFz1 and GtFz1 are specific variants of Fanzor that share similar properties and are also found in eukaryotic organisms.</p>
                    <p>CasX is a relatively new RNA-guided endonuclease, discovered in bacteria. It is smaller than the commonly used Cas9, making it an attractive option for applications where a more compact protein is beneficial. Like Cas9, CasX is capable of precise DNA targeting but offers advantages due to its reduced size and simpler structure.</p>
                </Collapsible>
                <p>In terms of the pegRNA, we opted for a pegRNA, including a 16-base primer binding site (PBS) and a 30-base reverse transcription template (RTT), with no silent edits and a structural motif, the tevopreQ1. After extensive screening using a reporter system, this pegRNA demonstrated the highest performance, leading us to select it as the best candidate for further development. While other pegRNAs also showed promise, pegRNA5 was ultimately chosen for its superior results in our testing.</p>
                <p>For the reverse transcriptase, we selected the P6C variant, which has shown to provide the best editing efficiency and a more compact structure compared to alternatives. Its advanced development stage and ability to offer high precision and editing performance made it the ideal choice for Prime Guide. </p>
                <p>Together, these components form a highly optimized Prime Editing system that balances size, stability, and efficiency. Our aim with Prime Guide is to create a robust and precise solution for correcting the F508del mutation in cystic fibrosis, building on the guidance from our expert collaborators and extensive testing of each individual component.</p>

                </Subesction>
                <Subesction title="Delivery" id="Approach2">
                    <div className='row align-items-center'>
                        <div className='col'>
                            <img src="https://static.igem.wiki/teams/5247/delivery/sort-lnp-ohne-beschriftung.webp"/>  
                        </div>
                        <div className='col'>
                        <p>We optimized LNPs as a robust delivery system to transport larger therapeutic cargo, such as Prime Editing mRNA, to lung epithelial cells via inhalation. LNPs were chosen over other delivery systems, like Adeno-associated viruses (AAVs), due to their superior cargo capacity and reduced immunogenicity. Our goal was to create a spray-dried lung-specific LNP named</p>
                        <img src="https://static.igem.wiki/teams/5247/delivery/airbuddy.webp" style={{maxHeight: "80pt"}}/>  
                        <p>capable of efficiently delivering of our Prime Editing components, referred to as PrimeGuide, to lung tissues through inhalation. This approach is designed to advance precision medicine by ensuring targeted delivery with minimal off-target effects.</p>
                        </div>
                    </div>
                    <Collapsible id="Col1" open={false} title="LNPs explained">
                         <H4 text="LNPs and their impact on modern medicine" id="text" /> 
                            <p>LNPs are an advanced delivery system designed to transport therapeutic molecules like RNA, DNA or proteins into the cells. These nanoparticles are tiny spheres made of lipids that form a protective shell around the cargo. The size of LNs typically ranges from 50 to 200 nm in diameter, making them incredibly small - about 1,000 times thinner than a human hair [1]. </p>
                            <p>Overall, LNPs represent a significant advancement in drug delivery technology. LNPs offer exceptionally high drug-loading capacities, making them highly effective for delivering substantial amounts of therapeutic agents in a single dose. Their advanced design allows for the encapsulation of a large payload, which enhances the efficacy of treatments and reduces the frequency of administration [3]. By encapsulating and protecting therapeutic agents like mRNA, LNPs enhance the stability, targeted delivery, and effectiveness of treatments. Their ability to be tailored for specific delivery needs, such as targeting particular organs or overcoming physiological barriers, makes them a powerful tool in modern medicine [9].</p>
                        <H4 text="Protection of cargo" id="text" /> 
                           <p> The primary function of LNPs is to shield the therapeutic agents they carry, such as mRNA, from degradation and facilitate their delivery into cells. mRNA is a critical component in many modern vaccines and therapies, but it is highly susceptible to breaking down before it can reach its target within cells. LNPs address this challenge by encapsulating the mRNA, thus protecting it from harmful enzymes, like RNases and environmental conditions [2]. </p>
                           <H4 text="Delivery assurance" id="text" /> 
                            <p>LNPs come in various types tailored for different therapeutic needs. Solid Lipid Nanoparticles (SLNs) and Nanostructured Lipid Carriers (NLCs) enhance drug stability and solubility, while Liposomes, with their bilayer structure, are versatile for encapsulating both hydrophilic and hydrophobic drugs. Cationic LNPs are ideal for gene delivery due to their positive charge, whereas anionic and neutral LNPs offer reduced interaction and lower toxicity, respectively [3]. </p>
                            <p>To enhance their effectiveness, LNPs are designed with specific components. For instance, the Nebulized Lung Delivery 1 (NLD1) nanoparticle, a particular type of LNP, includes a combination of lipids and polymers that stabilize the mRNA and allow it to be delivered efficiently. This formulation includes small lipid particles that encapsulate the mRNA and can maintain stability for several days under proper storage conditions [2]. </p>
                        <H4 text="Size impact of pulmonary LNPs" id="text" /> 
                        In the context of pulmonary delivery, where the goal is to target the lungs, the size and properties of the LNPs are crucial. Particles smaller than 2 micrometers are particularly effective for reaching the alveolar regions of the lungs [11]. 
                            <H4 text="Role of surface modifications in targeting" id="text" /> 
                            <div className='row align-items-center'>
                                <div className='col'>
                                    <figure> 
                                    <img src="https://ars.els-cdn.com/content/image/1-s2.0-S1773224724002156-gr3_lrg.jpg" alt="Aufnahme LNP" style={{maxHeight: "200pt"}}/> 
                                      <figcaption> 
                                      <b>Figure. </b> 
                                      Endosomal escape vs degradation of LNP cargo at endocytosis [4].
                                      </figcaption> 
                                     </figure> 
                                </div>
                             <div className='col'>
                             <p>LNPs are pivotal not only for shielding mRNA but also for ensuring its efficient delivery into target cells. They facilitate cellular uptake through endocytosis, where the cell membrane engulfs the nanoparticle. LNPs are acclaimed for their high drug-loading capacities, which greatly enhance their therapeutic effectiveness. However, the success of this delivery hinges on effective endosomal escape. Ideally, LNPs release their mRNA payload into the cytoplasm after escaping from endosomes. If this escape process is inefficient, the mRNA can be degraded by lysosomes, which poses a significant challenge for mRNA vaccines and therapies [4].</p>
                             </div>
                            </div>
                            <p>A crucial advancement in LNP technology involves the use of pH-sensitive cationizable lipids. These lipids remain neutral at physiological pH but become cationic in the acidic environment of endosomes. This shift in charge helps dissociate the nanoparticles and disrupt the endosomal membrane, enhancing the likelihood of successful endosomal escape [5]. </p>
                            <p>Moreover, the surface of LNPs can be customized to improve targeting. For instance, incorporating specific lipids or modifying the surface with charged groups can direct the delivery of mRNA to targeted organs like the lungs or spleen [6]. Additionally, LNPs can be engineered with targeting ligands or antibodies to precisely direct their payload to specific cell types, further enhancing their therapeutic efficacy [7]. Another approach can be chitosan-based nanoparticles have been explored for their ability to adhere to mucus and enhance drug delivery through the respiratory tract. These nanoparticles can penetrate through the mucus layer to reach the lung tissues more effectively [8]. This versatility in design is essential for optimizing the delivery and effectiveness of LNP-based therapies.</p>
                    </Collapsible>
                    <Collapsible id="Col2" open={false} title="Challenges of working with LNPs">
                            <p>Maintaining the stability of LNPs throughout formulation, storage, and delivery is critical, as factors like temperature changes, pH shifts, or mechanical stress can affect their integrity [1] [2]. Equally important is ensuring efficient encapsulation of the genetic material, as any inefficiency can lead to degradation of the therapeutic cargo or inadequate delivery to the target cells. Once inside the body, LNPs face the challenge of cellular uptake and successful endosomal escape [3] [4]. If they cannot escape the endosome after entering the cells, there is a risk that the genetic material will be degraded in the lysosomes, limiting the efficacy of the treatment. In addition, the formulation must minimize immunogenicity and toxicity, particularly with repeated dosing, which is often necessary for chronic diseases [2] [3]. Achieving this sensitive balance is crucial for maximizing the therapeutic potential of LNPs in gene delivery.</p>
                            <p>While these are general difficulties in the use of LNPs for gene therapy, further challenges arise when administering the LNPs via inhalation into the lungs, due to the unique environment and anatomy of the respiratory system.</p>
                    <H4 text="Challenges of inhalated lung-specific LNPs" id="chall2" /> 
                            <p>These challenges range from formulation and particle size to overcoming biological barriers and maintaining consistent dosing, all of which impact the overall efficacy of the therapy. </p>
                            <p>When transforming LNP formulations into inhalable particles, even greater attention must be paid to stability than is already the case. During processes like nebulization or spray-drying, LNPs are exposed to strong <strong>mechanical stress</strong> such as shear forces during aerosolization that can damage the LNP and thus their ability to protect and deliver genetic material effectively [5]. Ensuring that the LNPs maintain their structure throughout this transformation while remaining suitable for aerosol delivery is critical to the success of the therapy.</p>
                            <p>The <strong>size</strong> of the nanoparticles is another important factor. For successful lung delivery, LNPs should be smaller than 2 µm [6]. If the particles are too large, there is a risk that they will get stuck in the upper airways not able to reach the target cells; if they are too small, they may be exhaled before reaching the deeper lung tissue. The right particle size is crucial for the LNPs to reach the alveoli, where they can provide the greatest therapeutic impact.</p>
                            <p>Another major challenge is overcoming the lungs' natural <strong>protective barriers</strong>. The airways are lined with mucus and surfactants, which help to defend against pathogens, but also make it difficult for LNPs to be transported. In diseases such as cystic fibrosis, the thickened mucus presents an even greater obstacle, making it more difficult for the LNPs to reach the target cells [5]. The development of LNPs that can penetrate these barriers is essential for the success of gene therapy. </p>
                            <p>Finally, inhaled administration leads to fluctuations in the consistency of the <strong>dosage</strong>. Unlike intravenous administration, where dosing can be strictly controlled, the results of inhalation are influenced by factors such as the patient's breathing pattern, lung capacity and inhalation technique. These variables can affect how much of the LNP formulation actually reaches the lungs, complicating efforts to maintain a consistent therapeutic dose over time, which is a reasonable price to pay when you consider that inhalation is a non-invasive form of therapy compared to systemic therapy via injections into the bloodstream</p>
                            <p>All these challenges complicate the work with LNPs and present scientists with a great challenge, which makes working with LNPs even more important to find solutions.</p>
                    </Collapsible>
                    <br/>
                    <div className='row align-items-center'>
                        <p>To optimize AirBuddy for pulmonary delivery, we collaborated extensively with several experts, including <a onClick={() => goToPagesAndOpenTab('weber', '/human-practices')}>Prof. Weber, Dr. Große-Onnebrink</a> and <a onClick={() => goToPagesAndOpenTab('kolonkofirst', '/human-practices')}>Dr. Kolonko</a> as medical experts, <a onClick={() => goToPagesAndOpenTab('kristian', '/human-practices')}>Prof. Dr. Müller</a>, <a onClick={() => goToPagesAndOpenTab('radukic', '/human-practices')}>Dr. Radukic</a>, <a onClick={() => goToPagesAndOpenTab('moorlach', '/human-practices')}>Benjamin Moorlach</a> and the <a onClick={() => goToPagesAndOpenTab('biophysik', '/human-practices')}>Physical and Biophysical Chemistry working group</a> as academic experts form Bielefeld University and FH Bielefeld as well as <a onClick={() => goToPagesAndOpenTab('corden', '/human-practices')}>Corden Pharma</a> and <a onClick={() => goToPagesAndOpenTab('rnhale', '/human-practices')}>RNhale</a> as industrial experts. Throughout the <a onClick={() => goToPagesAndOpenTab('delivery head', '/engineering')}>development process</a>, we tested two commercially available kits: the <strong>Cayman Chemical LNP Exploration Kit (LNP-102)</strong> and the <strong>Corden Pharma LNP Starter Kit #2</strong>. While the Cayman kit demonstrated limited transfection efficiency, the Corden Pharma formulation significantly enhanced cellular uptake in lung tissues. Building on this, we integrated the <strong>SORT LNP</strong> method based on Wang's research [1], making our nanoparticles lung-specific. Additionally, we employed the <strong>spray-drying technique</strong> in cooperation with RNhale [2] to improve the stability of our LNP, ensuring that it withstands the inhalation process without degradation. This stability is crucial for the efficient delivery of mRNA into lung epithelial cells, where PrimeGuide can effectively perform genome editing.</p>
                        <img src="https://static.igem.wiki/teams/5247/delivery/big-plan-inhalation-teil-del.webp"/>  
                    </div>
                   <p>To evaluate the <strong>delivery efficiency</strong>, we transfected HEK293 and CFBE41o- cells using fluorescent cargo and quantified the results through FACS analysis. We also ensured that AirBuddy meets the necessary standards for safety and efficacy since we conducted extensive <a onClick={() => goToPageAndScroll ('In-Depth Characterization of LNPsH', '/materials-methods')}> characterization of the LNPs </a>using techniques such as Zeta potential analysis, Dynamic Light Scattering (DLS), Scanning Electron Microscopy (SEM), and Cryogenic Electron Microscopy (cryo-EM). These methods confirmed the uniformity, stability, and optimal size distribution of the nanoparticles. Furthermore, <strong>cytotoxicity assessments</strong> including MTT and proliferation assays demonstrated that our LNPs are biocompatible and do not impede cell growth or function by the incorporation of <a onClick={() => goToPagesAndOpenTab('it4', '/engineering')}>PEG</a> and other ambivalent components. These findings reinforce AirBuddy's potential as a safe and effective tool for pulmonary delivery, with broad implications for gene therapies targeting lung diseases.</p>
                </Subesction>
            </Section>
            <Section title="Our Achievement" id="Our Achievement">
                <p>Lorem Ipsum hier kommt noch ein banger text hin </p>
            </Section>
            <Section title="Our Vision" id="Our Vision">
                <p>At <b>PreCyse</b>, we envision a future where gene therapy for cystic fibrosis (CF) is as simple and user-friendly as using an inhaler. Our goal is to develop a fully integrated Prime Editing system, <b>PrimeGuide</b>, delivered via a cutting-edge lipid nanoparticle (LNP) platform, <b>AirBuddy</b>. The therapy would allow patients to inhale the therapeutic complex, targeting the underlying genetic mutation that causes CF—specifically, the F508del mutation in the CFTR gene. </p>
                <p>The core of our vision is to create a highly efficient and safe Prime Editing complex, referred to as Prime Guide, that is delivered directly into lung epithelial cells. This complex will be packaged as mRNA into LNPs, with an optimal ratio of the Prime Editing components and its guide RNA (pegRNA). Once inside the cell, the mRNA will be translated, forming the active Prime Editing complex, which then translocates into the nucleus using nuclear localization sequences. There, the complex will precisely edit the genome to correct the F508del mutation. </p>
                <p>To ensure safety, we are working on developing a robust mechanism that regulates the Prime Editing complex at the mRNA level. One concept we are exploring is using the XBP1 intron, which responds to cellular stress signals. Additionally, in the future, we aim to develop more mutation-specific control mechanisms, such as RNA riboswitches that activate the editing complex only in the presence of the target mutation, offering an even greater level of precision and safety. </p>
                <p>The long-term vision for PreCyse is to provide a gene therapy that can be administered through inhalation, much like an asthma spray. The patient would simply inhale the LNPs, which then deliver the therapeutic mRNA to the lungs. This approach offers a user-friendly and minimally invasive treatment that could suppress the symptoms of CF for several months. By correcting the mutation in the top layers of lung epithelial cells, where mucus buildup is most problematic, we could offer relief from symptoms over an extended period. However, since these epithelial cells naturally regenerate over time, the therapy would need to be reapplied periodically, likely every few months, balancing long-lasting effects with the need for occasional re-administration. </p>
                <p>Ultimately, our vision is to create a therapeutic approach that not only offers a cure that is safe and efficient but also maximizes convenience for the patient. With an easy-to-use inhaler, patients could administer their treatment with minimal disruption to their daily lives, inhaling the gene therapy in just a few breaths, leaving the rest of the process to the science we've built into PreCyse. By reducing the frequency of administration and simplifying the delivery method, we aim to make gene therapy for cystic fibrosis both accessible and practical for patients around the world. </p>
                <div className="casettecontainer" >
                    <img className="img" src="https://static.igem.wiki/teams/5247/delivery/big-plan-inhalation-del-mech.webp"/>
                </div>  
            </Section>
            <Section title="References" id="References">
                <ol>
                    {/* <!-- Citation num 1--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-1">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Scotet, V.</span>,
                            <span property="schema:Name">Gutierrez, H.</span>,
                            <span property="schema:Name">Farrell, P. </span>
                        </span>
                        <span property="schema:name">Newborn Screening for CF across the Globe—Where Is It Worthwhile? </span>
                        <i property="schema:publisher" typeof="schema:Organization">Int J Neonatal Screen </i>
                        <b property="issueNumber" typeof="PublicationIssue">6</b>,
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2020">2020</time>). 
                        <a className="doi" href="https://doi.org/10.3390/ijn6010018"> doi: 10.3390/ijn6010018</a>
                    </li>

                    {/* <!-- Citation num 2--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-2">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Anzalone, A.V.</span>,
                            <span property="schema:Name">Randolph, P.B.</span>,
                            <span property="schema:Name">Davis, J.R.</span>,
                            <span property="schema:Name">Sousa, A.A.</span>,
                            <span property="schema:Name">Koblan, L.W.</span>,
                            <span property="schema:Name">Levy, J.M.</span>,
                            <span property="schema:Name">Newby, G.A.</span>,
                            <span property="schema:Name">Raguram, A.</span>,
                            <span property="schema:Name">Liu, D.R. </span>
                        </span>
                        <span property="schema:name">Search-and-replace genome editing without double-strand breaks or donor DNA. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Nature </i>
                        <b property="issueNumber" typeof="PublicationIssue">574</b>,
                        <span property="schema:pageBegin"> 589</span>-<span property="schema:pageEnd">594 </span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2019">2019</time>).
                        <a className="doi" href="https://doi.org/10.1038/s41586-019-1711-4"> doi: 10.1038/s41586-019-1711-4</a>
                    </li>

                    {/* <!-- Citation num 3--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-3">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Broad Institute of MIT and Harvard. </span>
                        </span>
                        <span property="schema:name">Researchers engineer in vivo delivery system for prime editing, partially restoring vision in mice. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Phys.org </i>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2024">2024</time>).
                    </li>

                    {/* <!-- Citation num 4--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-4">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Gaudelli, N.</span>,
                            <span property="schema:Name">Komor, A.</span>,
                            <span property="schema:Name">Rees, H.</span>,
                            <span property="schema:Name">Packer, M.</span>,
                            <span property="schema:Name">Badran, A.</span>,
                            <span property="schema:Name">Bryson, D.</span>,
                            <span property="schema:Name">Liu, D. </span>
                        </span>
                        <span property="schema:name">Programmable editing of a target base in genomic DNA without double-stranded DNA cleavage. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Nature </i>
                        <b property="issueNumber" typeof="PublicationIssue">533</b>,
                        <span property="schema:pageBegin"> 420</span>-<span property="schema:pageEnd">424 </span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2016">2016</time>). 
                        <a className="doi" href="https://doi.org/10.1038/nature17946"> doi: 10.1038/nature17946</a>
                    </li>

                    {/* <!-- Citation num 5--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-5">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">OpenEd CUNY. </span>
                        </span>
                        <span property="schema:name">RNA Stability and the Role of RNA-Binding Proteins. </span>
                        <i property="schema:publisher" typeof="schema:Organization">OpenEd CUNY </i>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2024">2024</time>).
                    </li>

                    {/* <!-- Citation num 6--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-6">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Sahay, G.</span>,
                            <span property="schema:Name">Alakhova, D.Y.</span>,
                            <span property="schema:Name">Kabanov, A.V. </span>
                        </span>
                        <span property="schema:name">Endocytosis of nanomedicines. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Journal of Controlled Release </i>
                        <b property="issueNumber" typeof="PublicationIssue">145</b>,
                        <span property="schema:pageBegin"> 182</span>-<span property="schema:pageEnd">195 </span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2010">2010</time>).
                        <a className="doi" href="https://doi.org/10.1016/j.jconrel.2010.01.036"> doi: 10.1016/j.jconrel.2010.01.036</a>
                    </li>

                    {/* <!-- Citation num 7--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-7">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Ramachandran, S.</span>,
                            <span property="schema:Name">Satapathy, S.R.</span>,
                            <span property="schema:Name">Dutta, T. </span>
                        </span>
                        <span property="schema:name">Delivery Strategies for mRNA Vaccines. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Pharmaceutical Medicine </i>
                        <b property="issueNumber" typeof="PublicationIssue">36</b>,
                        <span property="schema:pageBegin"> 11</span>-<span property="schema:pageEnd">20 </span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2022">2022</time>).
                        <a className="doi" href="https://doi.org/10.1007/s40290-021-00417-5"> doi: 10.1007/s40290-021-00417-5</a>
                    </li>

                    {/* <!-- Citation num 8--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-8">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name">Bandi, S.P.</span>,
                            <span property="schema:Name">Bhatnagar, S.</span>,
                            <span property="schema:Name">Venuganti, V.V.K. </span>
                        </span>
                        <span property="schema:name">Advanced materials for drug delivery across mucosal barriers. </span>
                        <i property="schema:publisher" typeof="schema:Organization">Acta Biomaterialia </i>
                        <b property="issueNumber" typeof="PublicationIssue">119</b>,
                        <span property="schema:pageBegin"> 13</span>-<span property="schema:pageEnd">29 </span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime="2021">2021</time>).
                        <a className="doi" href="https://doi.org/10.1016/j.actbio.2020.10.031"> doi: 10.1016/j.actbio.2020.10.031</a>
                    </li>
                    {/*<!-- Citation num 9--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-9">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Anzalone, A.</span>;
                            <span property="schema:Name"> Randolph, P.</span>;
                            <span property="schema:Name"> Davis, J.</span>;
                            <span property="schema:Name"> Sousa, A.</span>;
                            <span property="schema:Name"> Koblan, L.</span>;
                            <span property="schema:Name"> Levy, J.</span>;
                            <span property="schema:Name"> Chen, P.</span>;
                            <span property="schema:Name"> Wilson, C.</span>;
                            <span property="schema:Name"> Newby, G.</span>;
                            <span property="schema:Name"> Raguram, A.</span>;
                            <span property="schema:Name"> Liu, D.</span>
                        </span>
                        <span property="schema:name">&nbsp;Search-and-replace genome editing without double-strand breaks or donor DNA. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Nature</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 576</b>,&nbsp;
                        <span property="schema:pageBegin">149–157</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2019">2019</time>).
                        <a className="doi" href="https://doi.org/10.1038/s41586-019-1711-4"> doi: 10.1038/s41586-019-1711-4</a>
                    </li>

                    {/*<!-- Citation num 10--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-10">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Doman, J.</span>;
                            <span property="schema:Name"> Pandey, S.</span>;
                            <span property="schema:Name"> Neugebauer, M.</span>;
                            <span property="schema:Name"> An, M.</span>;
                            <span property="schema:Name"> Davis, J.</span>;
                            <span property="schema:Name"> Randolph, P.</span>;
                            <span property="schema:Name"> McElroy, A.</span>;
                            <span property="schema:Name"> Gao, X.</span>;
                            <span property="schema:Name"> Raguram, A.</span>;
                            <span property="schema:Name"> Richter, M.</span>;
                            <span property="schema:Name"> Everette, K.</span>;
                            <span property="schema:Name"> Banskota, S.</span>;
                            <span property="schema:Name"> Tian, K.</span>;
                            <span property="schema:Name"> Tao, Y.</span>;
                            <span property="schema:Name"> Tolar, J.</span>;
                            <span property="schema:Name"> Osborn, M.</span>;
                            <span property="schema:Name"> Liu, D.</span>
                        </span>
                        <span property="schema:name">&nbsp;Phage-assisted evolution and protein engineering yield compact, efficient prime editors. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Cell</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 186</b>,&nbsp;
                        <span property="schema:pageBegin"> 3983</span>-<span property="schema:pageEnd">4002.e26</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2023">2023</time>).
                        <a className="doi" href="https://doi.org/10.1016/j.cell.2023.07.039"> doi: 10.1016/j.cell.2023.07.039</a>
                    </li>

                    {/*<!-- Citation num 11--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-11">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Jinek, M.</span>;
                            <span property="schema:Name"> Chylinski, K.</span>;
                            <span property="schema:Name"> Fonfara, I.</span>;
                            <span property="schema:Name"> Hauer, M.</span>;
                            <span property="schema:Name"> Doudna, J.</span>;
                            <span property="schema:Name"> Charpentier, E.</span>
                        </span>
                        <span property="schema:name">&nbsp;A programmable dual RNA-guided DNA endonuclease in adaptive bacterial immunity. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Science (New York, N.Y.)</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 337</b>,&nbsp;
                        <span property="schema:pageBegin">816–821</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2012">2012</time>).
                        <a className="doi" href="https://doi.org/10.1126/science.1225829"> doi: 10.1126/science.1225829</a>
                    </li>

                    {/*<!-- Citation num 12--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-12">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Nelson, J.</span>;
                            <span property="schema:Name"> Randolph, P.</span>;
                            <span property="schema:Name"> Shen, S.</span>;
                            <span property="schema:Name"> Everette, K.</span>;
                            <span property="schema:Name"> Chen, P.</span>;
                            <span property="schema:Name"> Anzalone, A.</span>;
                            <span property="schema:Name"> An, M.</span>;
                            <span property="schema:Name"> Newby, G.</span>;
                            <span property="schema:Name"> Chen, J.</span>;
                            <span property="schema:Name"> Hsu, A.</span>;
                            <span property="schema:Name"> Liu, D.</span>
                        </span>
                        <span property="schema:name">&nbsp;Engineered pegRNAs improve prime editing efficiency. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Nature Biotechnology</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 40</b>,&nbsp;
                        <span property="schema:pageBegin">402–410</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2022">2022</time>).
                        <a className="doi" href="https://doi.org/10.1038/s41587-021-01039-7"> doi: 10.1038/s41587-021-01039-7</a>
                    </li>

                    {/*<!-- Citation num 13--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-13">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Sousa, A.</span>;
                            <span property="schema:Name"> Hemez, C.</span>;
                            <span property="schema:Name"> Lei, L.</span>;
                            <span property="schema:Name"> Traore, S.</span>;
                            <span property="schema:Name"> Kulhankova, K.</span>;
                            <span property="schema:Name"> Newby, G.</span>;
                            <span property="schema:Name"> Doman, J.</span>;
                            <span property="schema:Name"> Oye, K.</span>;
                            <span property="schema:Name"> Pandey, S.</span>;
                            <span property="schema:Name"> Karp, P.</span>;
                            <span property="schema:Name"> McCray, P.</span>;
                            <span property="schema:Name"> Liu, D.</span>
                        </span>
                        <span property="schema:name">&nbsp;Systematic optimization of prime editing for the efficient functional correction of CFTR F508del in human airway epithelial cells. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Nature Biomedical Engineering</i>
                        <b property="issueNumber" typeof="PublicationIssue"> </b>,&;
                        <span property="schema:pageBegin">1–15</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2024">2024</time>).
                        <a className="doi" href="https://doi.org/10.1038/s41551-024-01233-3"> doi: 10.1038/s41551-024-01233-3</a>
                    </li>
                    {/*<!-- Citation num 14--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-14">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Rodrigues, R.</span>
                        </span>
                        <span property="schema:name">&nbsp;Cystic fibrosis and neonatal screening. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Cadernos de Saúde Pública</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 24</b>,&nbsp;
                        <span property="schema:pageBegin"> 475</span>-<span property="schema:pageEnd">484</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2008">2008</time>).
                        <a className="doi" href="https://doi.org/10.1590/S0102-311X2008001600002"> doi: 10.1590/S0102-311X2008001600002</a>
                    </li>

                    {/*<!-- Citation num 15--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-15">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Farrell, P.</span>
                        </span>
                        <span property="schema:name">&nbsp;The Impact of the CFTR Gene Discovery on Cystic Fibrosis Diagnosis, Counseling, and Preventive Therapy. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Genes</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 11(4)</b>,&nbsp;
                        <span property="schema:pageBegin">401</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2020">2020</time>).
                        <a className="doi" href="https://doi.org/10.3390/genes11040401"> doi: 10.3390/genes11040401</a>
                    </li>

                    {/*<!-- Citation num 16--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-16">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Lukacs, G.</span>
                        </span>
                        <span property="schema:name">&nbsp; CFTR: folding, misfolding and correcting the F508del conformational defect. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> Trends in molecular medicine</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 18(2)</b>,&nbsp;
                        <span property="schema:pageBegin"> 81</span>-<span property="schema:pageEnd">91</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2012">2012</time>).
                        <a className="doi" href="https://doi.org/10.1016/j.molmed.2011.10.003"> doi: 10.1016/j.molmed.2011.10.003</a>
                    </li>

                    {/*<!-- Citation num 17--> */}
                    <li typeof="schema:ScolarlyArticle" role="doc-biblioentry" property="schema:citation" id="desc-17">
                        <span property="schema:author" typeof="schema:Person">
                            <span property="schema:Name"> Amico, G.</span>
                        </span>
                        <span property="schema:name">&nbsp;Unravelling the Regions of Mutant F508del-CFTR More Susceptible to the Action of Four Cystic Fibrosis Correctors. </span>
                        <i property="schema:publisher" typeof="schema:Organization"> International Journal of Molecular Sciences</i>
                        <b property="issueNumber" typeof="PublicationIssue"> 20(21)</b>,&nbsp;
                        <span property="schema:pageBegin">5463</span>
                        (<time property="schema:datePublished" datatype="xsd:gYear" dateTime=" 2019">2019</time>).
                        <a className="doi" href="https://doi.org/10.3390/ijms20215463"> doi: 10.3390/ijms20215463</a>
                    </li>               
                </ol>
            </Section>


    

            


        </div>  
      </div>    
  );
}

 let medibuttonrowdata =[
    {
        node: createDrugSteckbrief(drugdata[0]), 
        buttonname: "Modulators", 
        cssname: "Med-First",
        main: true
        
    },
    {   
        node: createDrugSteckbrief(drugdata[1]),
        buttonname: "Mucolytics", 
        cssname: "Mucolytics"
    },
    {
        node: createDrugSteckbrief(drugdata[2]),
        buttonname: "Antibiotics", 
        cssname: "Antibiotics"
    },
    {
        node: createDrugSteckbrief(drugdata[3]),
        buttonname: "Enzymes", 
        cssname: "Enzymes"
    },
]



let symptombuttonrowdata = [
    {
        node: createSymptomSteckbrief(symptomdata[0]), 
        buttonname: "Pancreas", 
        cssname: "Symp-First",
        main: true
    },
    {   
        node: createSymptomSteckbrief(symptomdata[1]), 
        buttonname: "Intestines", 
        cssname: "intestines"
    },
    {
        node: createSymptomSteckbrief(symptomdata[2]), 
        buttonname: "Liver", 
        cssname: "liver"
    },
    {
        node: createSymptomSteckbrief(symptomdata[3]), 
        buttonname: "Sexual glands", 
        cssname: "Sexual glands"
    },
    {
        node: createSymptomSteckbrief(symptomdata[4]), 
        buttonname: "Lungs", 
        cssname: "lungs"
    },
    {
        node: createSymptomSteckbrief(symptomdata[5]), 
        buttonname: "Skeletal System", 
        cssname: "Skeletal System"
    },
    {
        node: createSymptomSteckbrief(symptomdata[6]), 
        buttonname: "Skin", 
        cssname: "skin"
    },
    {
        node: createSymptomSteckbrief(symptomdata[7]), 
        buttonname: "Nasal mucosa", 
        cssname: "Nasal mucosa"
    },
    {
        node: createSymptomSteckbrief(symptomdata[8]), 
        buttonname: "Brain", 
        cssname: "brain"
    },

]




function createSymptomSteckbrief(data: SymptomDatensatz){
    let examplelist: JSX.Element[] = []; 
    for (let index = 0; index < data.introduction.length; index++) {
            examplelist.push(
                <li key={index}>{data.introduction[index]}</li>
            )
    }
    return(
        <div>
            <H4 id={`${data.name}-btn`} text={data.name}/>
            <div className="row">
                <div className="col-2">
                    <div className="symptom-img-wrapper">
                        <img src={data.picture} className="symptom-img"/>
                    </div>
                </div>
                <div className="col">
                    <ul>{examplelist}</ul>
                </div>
            </div>
            
            
        </div>
    )
}


function createDrugSteckbrief(data: DrugDatensatz){
    let examplelist: JSX.Element[]  = []; 
    for (let index = 0; index < data.examples.length; index++) {
        let absaetze: JSX.Element[]  = []
        for (let i = 0; i < data.examples[index].text.length; i++) {
            absaetze.push(
                <li key={i}>{data.examples[index].text[i]}</li>
            )
            
        }
        examplelist.push(
            <div key={index+500} className="drug">
                <H4 text={data.examples[index].title}/>
                <ul key={index}>{absaetze}</ul>
            </div>
        )
        
    }
    return(
        <div>
            <H4 id={`${data.name}-btn`} text={data.name}/>
            <div className="row">
                <div className="col-2">
                    <div className="symptom-img-wrapper">
                        <img src={data.picture} className="symptom-img"/>
                    </div>
                </div>
                <div className="col">
                    {data.introduction}
                </div>
            </div>
            <div className="col">
            {examplelist}
            </div>
        </div>
    )
}